#!/bin/bash

IP=$1
if [ -z "$IP" ]; then
    echo "Usage: $0 IP"
    exit 1
fi


echo "Sending SSH keys..."
cat ~/sshkeys.txt | ssh root@$IP "mkdir -m 700 ~/.ssh; cat >> ~/.ssh/authorized_keys"

echo "Teleporting us to the remote machine via rsync"
ssh root@$IP aptitude --assume-yes install rsync
rsync -av . root@$IP:post-install

#ssh -t root@$IP cd post-install \&\& sh packages.sh
